@@ -147,43 +147,42 @@ JSON_WORKFLOW_ESTIMATION = {
 }
 
 JSON_ASSET = {
-    "data": {
-        "id": ASSET_ID,
-        "workspaceId": WORKSPACE_ID,
-        "createdAt": "2020-12-17T10:41:24.774111Z",
-        "type": "ARCHIVED",
-        "source": "BLOCK",
-        "name": "DS_PHR1B_201903161028440_FR1_PX_E008N47_0606_04372",
-        "size": 3920650,
-        "createdBy": {"id": "system", "type": "INTERNAL"},
-        "updatedBy": {"id": "system", "type": "INTERNAL"},
-        "updatedAt": "2020-12-17T10:41:24.774111Z",
-    },
-    "error": None,
+    "id": ASSET_ID,
+    "accountId": "69353acb-f942-423f-8f32-11d6d67caa77",
+    "workspaceId": WORKSPACE_ID,
+    "size": 256248634,
+    "name": "string",
+    "created": "2022-12-07T14:25:34.968Z",
+    "updated": "2022-12-07T14:25:34.968Z",
+    "contentType": "string",
+    "producerName": "string",
+    "collectionName": "string",
+    "productId": "3fa85f64-5717-4562-b3fc-2c963f66afa6",
+    "source": "ARCHIVE",
+    "order": {"id": "string", "status": "string", "hostId": "string"},
+    "title": "string",
+    "tags": ["string"],
 }
 
 JSON_ASSETS = {
-    "data": {
-        "content": [JSON_ASSET["data"]],
-        "pageable": {
-            "sort": {"sorted": True, "unsorted": False, "empty": False},
-            "pageNumber": 0,
-            "pageSize": 10,
-            "offset": 0,
-            "paged": True,
-            "unpaged": False,
-        },
-        "totalPages": 1,
-        "totalElements": 1,
-        "last": True,
+    "content": [JSON_ASSET],
+    "pageable": {
         "sort": {"sorted": True, "unsorted": False, "empty": False},
-        "numberOfElements": 1,
-        "first": True,
-        "size": 10,
-        "number": 0,
-        "empty": False,
+        "pageNumber": 0,
+        "pageSize": 10,
+        "offset": 0,
+        "paged": True,
+        "unpaged": False,
     },
-    "error": None,
+    "totalPages": 1,
+    "totalElements": 1,
+    "last": True,
+    "sort": {"sorted": True, "unsorted": False, "empty": False},
+    "numberOfElements": 1,
+    "first": True,
+    "size": 10,
+    "number": 0,
+    "empty": False,
 }
 
 JSON_ORDER = {
