@@ -1,10 +1,11 @@
 from typing import List, Union, Optional
 import math
+from datetime import datetime
 
 from up42.auth import Auth
 from up42.order import Order
 from up42.asset import Asset
-from up42.utils import get_logger
+from up42.utils import get_logger, format_time
 
 logger = get_logger(__name__)
 
@@ -46,9 +47,14 @@ class Storage:
         url = url + f"&size={size}"
 
         first_page_response = self.auth._request(request_type="GET", url=url)
-        num_pages = first_page_response["data"]["totalPages"]
-        num_elements = first_page_response["data"]["totalElements"]
-        results_list = first_page_response["data"]["content"]
+        if (
+            "data" in first_page_response
+        ):  # UP42 API v2 convention without data key, but still in e.g. get order
+            # endpoint
+            first_page_response = first_page_response["data"]
+        num_pages = first_page_response["totalPages"]
+        num_elements = first_page_response["totalElements"]
+        results_list = first_page_response["content"]
 
         if limit is None:
             # Also covers single page (without limit)
@@ -63,46 +69,59 @@ class Storage:
             response_json = self.auth._request(
                 request_type="GET", url=url + f"&page={page}"
             )
-            results_list += response_json["data"]["content"]
+            if "data" in response_json:
+                response_json = response_json["data"]
+            results_list += response_json["content"]
         return results_list[:limit]
 
     def get_assets(
         self,
-        return_json: bool = False,
+        created_after: Optional[Union[str, datetime]] = None,
+        created_before: Optional[Union[str, datetime]] = None,
+        workspace_id: Optional[str] = None,
         limit: Optional[int] = None,
-        sortby: str = "createdAt",
+        sortby: str = "created",
         descending: bool = True,
+        return_json: bool = False,
     ) -> Union[List[Asset], dict]:
         """
-        Gets all assets in the workspace as Asset objects or json.
+        Gets all assets in all your accessible workspaces as Asset objects or json.
 
         Args:
-            return_json: If set to True, returns json object.
+            created_after: Only assets that are created strictly after the provided timestamp, datetime or
+                isoformat string e.g. "2022-01-01",
+            created_before: Only assets that are created strictly before the provided timestamp, datetime or
+                isoformat string e.g. "2022-01-30"
+            workspace_id: Only assets that belong to the provided workspace. You can use `storage.workspace_id` here
+                to limit to your own workspace.
             limit: Optional, only return n first assets by sorting criteria and order.
                 Optimal to select if your workspace contains many assets.
-            sortby: The sorting criteria, one of "createdAt", "updatedAt", "source", "type",
-                "name", "size".
+            sortby: The sorting criteria, one of "created", "updated", "title", "name", "size", "contentType",
+                "collectionName", "producerName", "workspaceId", "accountId", "id"
             descending: The sorting order, True for descending (default), False for ascending.
+            return_json: If set to True, returns json object.
 
         Returns:
             Asset objects in the workspace or alternatively json info of the assets.
         """
-        allowed_sorting_criteria = [
-            "createdAt",
-            "updatedAt",
-            "source",
-            "type",
-            "name",
-            "size",
-        ]
-        if sortby not in allowed_sorting_criteria:
-            raise ValueError(
-                f"sortby parameter must be one of {allowed_sorting_criteria}!"
-            )
         sort = f"{sortby},{'desc' if descending else 'asc'}"
-        url = f"{self.auth._endpoint()}/workspaces/{self.workspace_id}/assets?format=paginated&sort={sort}"
+        url = f"{self.auth._endpoint()}/v2/assets?sort={sort}"
+        if created_after is not None:
+            url += f"&createdAfter={format_time(created_after)}"
+        if created_before is not None:
+            url += f"&createdBefore={format_time(created_before)}"
+        if workspace_id is not None:
+            url += f"&workspaceId={workspace_id}"
+
         assets_json = self._query_paginated(url=url, limit=limit)
-        logger.info(f"Got {len(assets_json)} assets for workspace {self.workspace_id}.")
+        if workspace_id is not None:
+            logger.info(
+                f"Queried {len(assets_json)} assets for workspace {self.workspace_id}."
+            )
+        else:
+            logger.info(
+                f"Queried {len(assets_json)} assets from all workspaces in account."
+            )
 
         if return_json:
             return assets_json  # type: ignore
